Module objects

Module objects 

Structs

Arenas
Arena for semantic expressions, patterns, and statements.
ExprArenaBehavior
ExprAssignment
ExprBlock
ExprClosure
ExprConstant
ExprDesnap
ExprEnumVariantCtor
ExprFixedSizeArray
ExprFor
ExprFunctionCall
ExprId
ExprIf
ExprLogicalOperator
ExprLoop
ExprMatch
ExprMemberAccess
ExprMissing
ExprNumericLiteral
ExprPropagateError
ExprSnapshot
ExprStringLiteral
ExprStructCtor
ExprTuple
ExprUse
ExprVar
ExprWhile
MatchArm
PatternArenaBehavior
PatternId
StatementArenaBehavior
StatementBreak
StatementContinue
StatementExpr
StatementId
StatementItem
StatementLet
StatementReturn

Enums

Condition
Expr
ExprFunctionCallArg
ExprVarMemberPath
A sequence of member accesses of a variable. For example: a, a.b, a.b.c, …
FixedSizeArrayItems
Either a vector of items, if all was written in the code i.e. ([10, 11, 12] or [10, 10, 10]), or a value and a size, if the array was written as ([10; 3]).
LogicalOperator
MemberAccessKind
Identifies the accessed member of an aggregate, either a named struct member or a positional element of a tuple (e.g. t.0).
Statement

Type Aliases

ExprArena
PatternArena
StatementArena