pub enum ExprFunctionCallArg<'db> {
Reference(ExprVarMemberPath<'db>),
Value(ExprId),
TempReference(ExprId),
}Variants
Reference(ExprVarMemberPath<'db>)
Value(ExprId)
TempReference(ExprId)
An argument for function calls which is an expression result, but expected to be taken as
reference. Only valid for the first parameter of method calls with ref self.