pub struct PatternWrappingInfo {
pub n_outer_snapshots: usize,
pub n_boxed_inner_snapshots: Option<usize>,
}Expand description
Information about how a type is wrapped for pattern matching.
Fields
n_outer_snapshots: usizeNumber of outer snapshot wrappers (e.g., @Box<Enum> has 1 outer snapshot).
n_boxed_inner_snapshots: Option<usize>If the type is wrapped in a Box, contains the number of inner snapshots
(e.g., Box<@Enum> has Some(1), Box<Enum> has Some(0), non-boxed has None).
Implementations